@@ -39,17 +39,22 @@ import joblib
 
 def EIS_to_cap_retention_off_gbr(filename):
     '''
+    offline gradient boosting regressor for capacity retention prediction after 200 cycles
     
-
     Parameters
     ----------
-    filename : TYPE
-        DESCRIPTION.
+    filename : str
+        file name of the impedacne data interested.
 
     Returns
     -------
-    None. Based on 40 battery data
-
+    The capacity retention after 200 cycles based on 40 battery data.
+    The first value is the predicted retention
+    The second value is the lower limit of the 90 percent confidence intervale 
+    The third value is the upper limit of the 90 percent confidence intervale 
+    
+    Values are in percentage
+    
     '''
     df=pd.DataFrame()
     Z=pd.DataFrame()
@@ -59,21 +64,38 @@ def EIS_to_cap_retention_off_gbr(filename):
     gbr=joblib.load('data/gbr_model.sav')
     gbr_upper=joblib.load('data/gbr_upper_interval.sav')
     gbr_lower=joblib.load('data/gbr_lower_interval.sav')
-    return(gbr.predict(Z),gbr_lower.predict(Z),gbr_upper.predict(Z))
+    
+    y_pred = round(gbr.predict(Z)*100,2)
+    y_lower = round(gbr_lower.predict(Z)*100,2)
+    y_upper = round(gbr_upper.predict(Z)*100,2)
+    
+    return(y_pred,y_lower,y_upper)
 
 
 def EIS_to_cap_retention_onl_gbr(filename,learning_rate , n_estimators, max_depth):
     '''
-    
+    online gradient boosting regressor for capacity retention prediction after 200 cycles
+
 
     Parameters
     ----------
-    filename : TYPE
-        DESCRIPTION.
+    filename : str
+        file name of the impedacne data interested.
+    learning_rate : float
+        learning rate of the machine learning model should be from 0 to 1.
+    n_estimators : int
+        number of estimators.
+    max_depth : int
+        maximum depth for the regressor.
 
     Returns
     -------
-    None. Based on 40 battery data
+    The capacity retention after 200 cycles based on 40 battery data.
+    The first value is the predicted retention
+    The second value is the lower limit of the 90 percent confidence intervale 
+    The third value is the upper limit of the 90 percent confidence intervale .
+    
+    Values are in percentage
 
     '''
     Z1=loadtxt('data/Z1_10.csv',delimiter=',')
@@ -100,9 +122,9 @@ def EIS_to_cap_retention_onl_gbr(filename,learning_rate , n_estimators, max_dept
     for alpha in [0.05,0.95]:
         gbr_int = GradientBoostingRegressor(loss="quantile", alpha=alpha, **common_params)
         confident_interval["q %1.2f" % alpha] = gbr_int.fit(X_train, y_train)
-    y_pred = gbr.predict(Z)
-    y_lower = confident_interval["q 0.05"].predict(Z)
-    y_upper = confident_interval["q 0.95"].predict(Z)
+    y_pred = round(gbr.predict(Z)*100,2)
+    y_lower = round(confident_interval["q 0.05"].predict(Z)*100,2)
+    y_upper = round(confident_interval["q 0.95"].predict(Z)*100,2)
     return(y_pred,y_lower,y_upper)
     
 def EIS_to_cap_retention_off_rdf(filename):
@@ -111,12 +133,18 @@ def EIS_to_cap_retention_off_rdf(filename):
 
     Parameters
     ----------
-    filename : TYPE
-        DESCRIPTION.
+    offline random forest regressor for capacity retention prediction after 200 cycles
+    
+    Parameters
+    ----------
+    filename : str
+        file name of the impedacne data interested.
 
     Returns
     -------
-    None. Based on 40 battery data
+    The predicted capacity retention after 200 cycles based on 40 battery data.
+    
+    Values are in percentage
 
     '''
     df=pd.DataFrame()
@@ -126,22 +154,32 @@ def EIS_to_cap_retention_off_rdf(filename):
     Z=Z.reshape(1, -1)
     rdf=joblib.load('data/rdf_model.sav')
    
-    return(rdf.predict(Z))
+    return(round(rdf.predict(Z)*100,2))
 
 
 
 def EIS_to_cap_retention_onl_rdf(filename,n_estimators,max_features):
     '''
     
+    online random forest regressor for capacity retention prediction after 200 cycles
+
 
     Parameters
     ----------
-    filename : TYPE
-        DESCRIPTION.
+    filename : str
+        file name of the impedacne data interested.
+    
+    n_estimators : int
+        number of estimators.
+    max_features : int
+        maximum features for the regressor.
 
     Returns
     -------
-    None. Based on 40 battery data
+    The predicted capacity retention after 200 cycles based on 40 battery data.
+    
+    Values are in percentage
+
 
     '''
     Z1=loadtxt('data/Z1_10.csv',delimiter=',')
@@ -157,58 +195,8 @@ def EIS_to_cap_retention_onl_rdf(filename,n_estimators,max_features):
     
     clf_random = RandomForestRegressor(n_estimators=n_estimators, random_state=10,max_features=max_features)
     clf_random = clf_random.fit(X_train, y_train)
-    return(clf_random.predict(Z))
-    
-    
-# def Vol_to_cap_retention_off_gbr(filename):
-#     '''
-    
-
-#     Parameters
-#     ----------
-#     filename : TYPE
-#         DESCRIPTION.
-
-#     Returns
-#     -------
-#     None. Based on 40 battery data
-
-#     '''
-#     df=pd.DataFrame()
-#     Z=pd.DataFrame()
-#     df=impedance_data_processing(filename).dropna()
-#     Z=np.append(df['Z1'][0:-1],df['Z2'][0:-1],axis=0)
-    
-#     Z=Z.reshape(1, -1)
-    
-#     gbr=joblib.load('gbr_model.sav')
-#     gbr_upper=joblib.load('gbr_upper_interval.sav')
-#     gbr_lower=joblib.load('gbr_lower_interval.sav')
-#     return(gbr.predict(Z),gbr_lower.predict(Z),gbr_upper.predict(Z))
-    
-# def Vol_to_cap_retention_off_rdf(filename):
-#     '''
-    
-
-#     Parameters
-#     ----------
-#     filename : TYPE
-#         DESCRIPTION.
-
-#     Returns
-#     -------
-#     None. Based on 40 battery data
-
-#     '''
-#     df=pd.DataFrame()
-#     Z=pd.DataFrame()
-#     df=impedance_data_processing(filename).dropna()
-#     Z=np.append(df['Z1'][0:-1],df['Z2'][0:-1],axis=0)
-#     Z=Z.reshape(1, -1)
-#     rdf=joblib.load('rdf_model.sav')
-   
-#     return(rdf.predict(Z))
-    
+    return(round(clf_random.predict(Z)*100,2))
+ 
     
     
     
